@@ -79,10 +79,12 @@ static bool desktopFilePresent(const QString &constraint, const QJsonValue &valu
     return !QStandardPaths::locate(QStandardPaths::ApplicationsLocation, constraint).isEmpty();
 }
 
-static QMap<QString, matchFunction> s_matchFunctions = {{QStringLiteral("mimeType"), mimeTypeMatch},
-                                                        {QStringLiteral("dbus"), dbusMatch},
-                                                        {QStringLiteral("application"), desktopFilePresent},
-                                                        {QStringLiteral("exec"), executablePresent}};
+static QMap<QString, matchFunction> s_matchFunctions = {
+    {QStringLiteral("mimeType"), mimeTypeMatch},
+    {QStringLiteral("dbus"), dbusMatch},
+    {QStringLiteral("application"), desktopFilePresent},
+    {QStringLiteral("exec"), executablePresent},
+};
 
 class Purpose::AlternativesModelPrivate
 {
@@ -97,7 +99,7 @@ public:
     bool isPluginAcceptable(const KPluginMetaData &meta, const QStringList &disabledPlugins) const
     {
         const QJsonObject obj = meta.rawData();
-        if (!obj.value(QStringLiteral("X-Purpose-PluginTypes")).toArray().contains(m_pluginType)) {
+        if (!obj.value(QLatin1String("X-Purpose-PluginTypes")).toArray().contains(m_pluginType)) {
             // qDebug() << "discarding" << meta.name() << KPluginMetaData::readStringList(meta.rawData(), QStringLiteral("X-Purpose-PluginTypes"));
             return false;
         }
@@ -108,7 +110,7 @@ public:
         }
 
         // All constraints must match
-        const QJsonArray constraints = obj.value(QStringLiteral("X-Purpose-Constraints")).toArray();
+        const QJsonArray constraints = obj.value(QLatin1String("X-Purpose-Constraints")).toArray();
         for (const QJsonValue &constraint : constraints) {
             if (!constraintMatches(meta, constraint))
                 return false;
@@ -255,7 +257,7 @@ QVariant AlternativesModel::data(const QModelIndex &index, int role) const
     case PluginIdRole:
         return data.pluginId();
     case ActionDisplayRole: {
-        const auto pluginData = data.rawData()[QStringLiteral("KPlugin")].toObject();
+        const QJsonObject pluginData = data.rawData().value(QLatin1String("KPlugin")).toObject();
         const QString action = KJsonUtils::readTranslatedString(pluginData, QStringLiteral("X-Purpose-ActionDisplay"));
         return action.isEmpty() ? data.name() : action;
     }
@@ -296,7 +298,7 @@ void AlternativesModel::initializeModel()
         return;
     }
 
-    const QJsonArray inbound = d->m_pluginTypeData.value(QStringLiteral("X-Purpose-InboundArguments")).toArray();
+    const QJsonArray inbound = d->m_pluginTypeData.value(QLatin1String("X-Purpose-InboundArguments")).toArray();
     for (const QJsonValue &arg : inbound) {
         if (!d->m_inputData.contains(arg.toString())) {
             qWarning().nospace() << "Cannot initialize model with data " << d->m_inputData << ". missing: " << arg;
